pub struct ChatRunner { /* private fields */ }Expand description
Shared runner for provider adapters that differ only by wire dialect.
Implementations
Sourceimpl ChatRunner
impl ChatRunner
Sourcepub fn new(system: &'static str, default_model: impl Into<String>) -> Self
pub fn new(system: &'static str, default_model: impl Into<String>) -> Self
Create a runner with the provider system name and default model.
Sourcepub fn with_policy(self, policy: Policy) -> Self
pub fn with_policy(self, policy: Policy) -> Self
Inject a resilience policy for outbound completion requests.
Sourcepub async fn complete<F, Fut>(
&self,
req: CompletionRequest,
complete_once: F,
) -> AppResult<CompletionResponse>where
F: Fn(CompletionRequest) -> Fut + Send + Sync,
Fut: Future<Output = AppResult<CompletionResponse>> + Send,
pub async fn complete<F, Fut>(
&self,
req: CompletionRequest,
complete_once: F,
) -> AppResult<CompletionResponse>where
F: Fn(CompletionRequest) -> Fut + Send + Sync,
Fut: Future<Output = AppResult<CompletionResponse>> + Send,
Complete a request using provider-specific wire conversion.